@@ -14,6 +14,7 @@
 
 #include <cmath>
 #include "newmatap.h"
+#include "string"
 
 using namespace NEWMAT;
 
@@ -22,12 +23,13 @@ namespace MISCMATHS {
 float optimise1d(ColumnVector &pt, const ColumnVector dir, 
 		const ColumnVector tol, int &iterations_done, 
 		float (*func)(const ColumnVector &), int max_iter,
-		float init_value, float boundguess);
+		float &init_value, float boundguess);
 
 
  float optimise(ColumnVector &pt, int numopt, const ColumnVector &tol, 
 		float (*func)(const ColumnVector &), int &iterations_done, 
-		int max_iter, const ColumnVector& boundguess);
+		int max_iter, const ColumnVector& boundguess, 
+		const std::string type="brent");
 
 }
 
