@@ -102,7 +102,7 @@ public:
   }
   T ValAndDerivs(double x, double y, double z, std::vector<T>& rderiv) const;
 
-  // Return continous derivative at voxel centres (only works for order<1)
+  // Return continous derivative at voxel centres (only works for order>1)
   T Deriv(const std::vector<unsigned int>& indx, unsigned int ddir) const;
   T Deriv1(const std::vector<unsigned int>& indx) const {return(Deriv(indx,0));}
   T Deriv2(const std::vector<unsigned int>& indx) const {return(Deriv(indx,1));}
@@ -644,7 +644,7 @@ double Splinterpolator<T>::value_and_derivatives_at(const double       *coord,
 						    double             *dval) 
 const
 {
-  if (should_be_zero(coord)) { memset(dval,n_nonzero(deriv)*sizeof(double),0); return(0.0); }
+  if (should_be_zero(coord)) { memset(dval,0,n_nonzero(deriv)*sizeof(double)); return(0.0); }
 
   double       iwgt[8], jwgt[8], kwgt[8], lwgt[8], mwgt[8];
   double       *wgts[] = {iwgt, jwgt, kwgt, lwgt, mwgt};
@@ -1153,10 +1153,10 @@ inline unsigned int Splinterpolator<T>::indx2indx(int indx, unsigned int d) cons
       return(0);
       break;
     case Zeros: case Mirror:
-      return(1-indx);
+      return((indx%int(_dim[d])) ? _dim[d]-1 : -1-indx%int(_dim[d]));
       break;
     case Periodic:
-      return(_dim[d]+indx);
+      return((indx%int(_dim[d])) ? _dim[d]+indx%int(_dim[d]) : 0);
       break;
     default:
       break;
@@ -1168,10 +1168,10 @@ inline unsigned int Splinterpolator<T>::indx2indx(int indx, unsigned int d) cons
       return(_dim[d]-1);
       break;
     case Zeros: case Mirror:
-      return(2*_dim[d]-indx-1);
+      return(2*_dim[d] - (_dim[d]+indx%int(_dim[d])) - 1);
       break;
     case Periodic:
-      return(indx-_dim[d]);
+      return(indx%int(_dim[d]));
       break;
     default:
       break;
