@@ -6,6 +6,8 @@
 
 namespace Utilities {
 
+  using namespace std;
+
   bool OptionParser::check_compulsory_arguments(bool verbose)
   {
     bool okay = true;
@@ -23,7 +25,7 @@ namespace Utilities {
 	  okay = false;
 	}
 	if(verbose)
-	  cerr << **option << endl;
+	  (*option)->usage(cerr); cerr << endl;
       }
     }
     if(!okay && verbose)
