@@ -7,7 +7,7 @@
 /*  CCOPYRIGHT */
 
 /****************************************************************************
-** $Id: application.h,v 1.57 2009/04/28 14:56:39 flitney Exp $
+** $Id: application.h,v 1.57.6.4 2012/09/10 00:25:32 flitney Exp $
 **
 ** Copyright (C) 2002 University of Oxford.  All rights reserved.
 **
@@ -20,7 +20,12 @@
 #pragma warning(disable:4786)
 #endif
 
-#include <qmainwindow.h>
+#include <qobject.h>
+#include <QMainWindow>
+//Added by qt3to4:
+#include <QLabel>
+//#include <Q3PopupMenu>
+#include <QCloseEvent>
 #include "cursor.h"
 #include <qlist.h>
 #include "imagegroup.h" 
@@ -36,10 +41,10 @@
 class QLabel;
 class QString;
 class QStatusBar;
-class QScrollView;
-class QMultiLineEdit;
-class QToolBar;
-class QPopupMenu;
+//class Q3ScrollView;
+//class Q3MultiLineEdit;
+//class Q3ToolBar;
+//class Q3PopupMenu;
 class QWorkspace;
 class FileError;
 class ViewWidget;
@@ -48,7 +53,7 @@ class QAssistantClient;
 
 #include "applicationwindowbase.h"
 
-class ApplicationWindow: public ApplicationWindowBase, 
+class ApplicationWindow: public QMainWindow, private Ui_ApplicationWindowBase, 
 			 public CursorObserver
 {
   Q_OBJECT
@@ -71,15 +76,25 @@ public:
   void setFileMenuItemsState(void);
 
 private slots:
-  void fileOpen();
-  void fileOpen152();
-  void fileSaveAs();
-  void fileAdd();
-  void fileAdd152();
-  void fileRemove();
-  void fileCreateMask();
-  void fileCloseWindow();
+  void on_fileOpenAction_triggered();
+  void on_fileOpen152Action_triggered();
+  void on_fileSaveAsAction_triggered();
+  void on_fileAddAction_triggered();
+  void on_fileAdd152Action_triggered();
+  void on_fileRemoveAction_triggered();
+  void on_fileCreateMaskAction_triggered();
+  void on_fileCloseAction_triggered();
+  void on_filePreferencesAction_triggered();
 
+  void on_fileMenu_aboutToShow();
+  void on_Window_aboutToShow();
+  void on_Tools_aboutToShow();
+
+//  void on_Window_activated(int);
+  void on_mdiArea_subWindowActivated(QMdiSubWindow*);
+//  void on_fileMenu_aboutToHide();
+
+  void windowMenuActivated(int);
 //   void windowCascade();
 //   void windowTile();
 
@@ -91,12 +106,6 @@ private slots:
   void viewImageHistogram();
   void viewClusterBrowser();
 
-  void filePreferences();
-
-  void fileMenuAboutToShow();  
-  void viewMenuAboutToShow();
-  void windowMenuAboutToShow();
-  void windowMenuActivated( int id );
   void displayMessage(const QString &, int);
   void setMenuItems_NoImages(void);
 
@@ -117,7 +126,7 @@ signals:
   void workSpaceEmpty(void);
 
 private:
-  QWorkspace* m_ws;
+  //  QWorkspace* m_ws;
 //   QMenuBar* m_mb;
 //   QPopupMenu* m_fileMenu;
 //   QPopupMenu* m_windowsMenu;
@@ -155,8 +164,8 @@ private:
   QString            m_filename;
   QStatusBar        *m_statusBar;
 
-  QPopupMenu        *m_viewMenu;
-  QScrollView       *m_sv;
+//  Q3PopupMenu        *m_viewMenu;
+//  Q3ScrollView       *m_sv;
 
   QAssistantClient  *m_assistant;
   ImageGroup::Handle m_imageGroup;
