@@ -11,13 +11,14 @@
 #if !defined(ASSISTANTCLIENT_H)
 #define ASSISTANTCLIENT_H
 
-#include <qassistantclient.h>
+//#include <qassistantclient.h>
 
 class QString;
 
-class AssistantClient: public QAssistantClient
+//class AssistantClient: public QAssistantClient
+class AssistantClient
 {
-Q_OBJECT
+//Q_OBJECT
 public:
   static AssistantClient* getInstance();
 
