@@ -24,7 +24,7 @@
 
 class AtlasOptions;
 
-class AtlasOptionsDialog : public AtlasOptionsDialogBase
+class AtlasOptionsDialog : public QDialog, private Ui::AtlasOptionsDialogBase
 {
 Q_OBJECT
 
