@@ -19,7 +19,7 @@
 
 class QStringList;
 
-class AtlasSelectionDialog : public  AtlasSelectionDialogBase
+class AtlasSelectionDialog : public QDialog, private Ui_AtlasSelectionDialogBase
 {
 Q_OBJECT
 
@@ -34,7 +34,7 @@ public:
   void enableAtlas(Atlas::Handle);
 
 private slots:
-  void toggleDisplayAtlas(QListViewItem* i);
+  void toggleDisplayAtlas(Q3ListViewItem* i);
 
 private:
   struct Implementation;
