@@ -24,7 +24,8 @@
 //! @brief Implentation of BriCon toolbar behaviour
 //!
 //! @author Dave Flitney
-class BriConWidget : public BriConWidgetBase, BriConObserver, OverlayListObserver
+class BriConWidget : public QWidget, private Ui::BriConWidgetBase, 
+  public BriConObserver, OverlayListObserver
 {
   Q_OBJECT
 public:
@@ -40,6 +41,10 @@ public:
   void setBriSliderState(bool state);
   void setConSliderState(bool state);
 
+public slots:
+
+  void reset();
+
 private:
   
   BriCon::Handle        m_bricon;
@@ -51,12 +56,20 @@ private:
 
 private slots:
 
-  void reset();
+  void on_minBox_lostFocus() 		{ minChanged(); }
+  void on_maxBox_lostFocus()		{ maxChanged(); }
+  void on_minBox_returnPressed()	{ minChanged(); }
+  void on_maxBox_returnPressed()	{ maxChanged(); }
+
+  void on_briSlider_valueChanged(double);
+  void on_conSlider_valueChanged(double);
+  void on_briSlider_sliderReleased()	{ slidersChanged(); }
+  void on_conSlider_sliderReleased()	{ slidersChanged(); }
+
+private:
   void minChanged();
   void maxChanged();
-  void briSliderChanged(double value);
-  void conSliderChanged(double value);
-  void sliderReleased();
+  void slidersChanged();
 };
 
 #endif
