@@ -24,8 +24,10 @@
 #include "storage/image.h"
 
 #include <vector>
+//Added by qt3to4:
+//#include <QCloseEvent>
 
-class ClusterBrowser: public ClusterBrowserBase
+class ClusterBrowser: public QMainWindow, private Ui::ClusterBrowserBase
 {
   Q_OBJECT
 
@@ -43,14 +45,15 @@ signals:
   void windowClose(QCloseEvent*);
 
 private slots:
-  void selectStatistic(int);
-  void clusterListSelectionChanged(QListViewItem *);
-  void showTalairach(bool);
+  void on_statComboBox_currentIndexChanged(int);
+  void on_clusterListView_selectionChanged(Q3ListViewItem *);
+  void on_talairachCheckBox_clicked(bool);
 protected:
   virtual void closeEvent(QCloseEvent*);
 
 private:
 
+  bool m_initialised;
   bool m_showTalairach;
   unsigned short m_currentSelection;
   std::vector<ClusterTable> m_clusterTables;
