@@ -14,13 +14,13 @@
 #include <qtooltip.h>
 #include <qlayout.h>
 #include <qlabel.h>
-#include <qvbox.h>
+#include <q3vbox.h>
 #include <qcolor.h>
-#include <qcstring.h>
+#include <q3cstring.h>
 
 #include <algorithm>
 #include <stdio.h>
-#include <qcanvas.h>
+#include <q3canvas.h>
 #include <qtimer.h>
 
 //#include "fill.xpm"
@@ -35,10 +35,12 @@
 #include "tracker.h"
 
 DrawWidget::DrawWidget(QWidget* w, OverlayList::Handle ol, DrawSettings::Handle ds):
-  DrawToolbarBase(w),
+  QWidget(w),
   m_overlayList(ol),
   m_drawSettings(ds)
 {
+  setupUi(this);
+
   connect(m_valBox,      SIGNAL(valueChanged(int)), SLOT(valBoxChanged(int)));
   connect(m_sizeBox,     SIGNAL(valueChanged(int)), SLOT(sizeBoxChanged(int)));
  
@@ -51,7 +53,7 @@ DrawWidget::DrawWidget(QWidget* w, OverlayList::Handle ol, DrawSettings::Handle
   connect(m_undoButton,  SIGNAL(clicked()),         SIGNAL(undoButtonClicked()));
   connect(m_redoButton,  SIGNAL(clicked()),         SIGNAL(redoButtonClicked()));
 
-  m_undoButton->setAccel(CTRL+Key_Z);
+  m_undoButton->setAccel(Qt::CTRL+Qt::Key_Z);
 
   m_overlayList->attach(this);
   MetaImage::Handle mi = ol->getActiveMetaImage();
@@ -134,7 +136,7 @@ void DrawWidget::updateControls()
     QPixmap colorPixmap = QPixmap( *(m_colorPixmapLabel->pixmap()) );
     if(lut->isIndexLut()) {
       const LutElement& penColor = lut->inqValueIndex(m_drawSettings->inqPenValue());
-      MESSAGE(QString("...to: %1 %2 %3").arg(penColor.red()).arg(penColor.green()).arg(penColor.blue()) );
+      MESSAGE(QString("...to: %1 %2 %3").arg(penColor.Qt::red()).arg(penColor.Qt::green()).arg(penColor.Qt::blue()) );
       colorPixmap.fill( QColor(penColor.red(), penColor.green(), penColor.blue()) );
     } else {
       const LutElement& penColor = lut->inqValue(briCon->adjust(m_drawSettings->inqPenValue()));
@@ -163,7 +165,7 @@ void DrawWidget::update(const BriCon* b)
     if(m_valBox->value() < b->inqMin()
     || m_valBox->value() > b->inqMax())
       {
-	m_valBox->setValue(int(b->inqMin()));
+	m_valBox->setValue(b->inqMin());
       }
   }
   else return; 
