@@ -21,11 +21,11 @@
 
 #include <sstream>
 
-#include <qobject.h>
-#include <qstringlist.h>
-#include <qfile.h>
-#include <qdir.h>
-#include <qdom.h>
+#include <QtCore/QObject>
+#include <QtCore/QStringList>
+#include <QtCore/QFile>
+#include <QtCore/QDir>
+#include <QtXml/qdom.h>
 
 using namespace std;
 
@@ -256,7 +256,7 @@ LutElement readColourNode( QDomNode &node )
   QStringList colours( QStringList::split(",", node.firstChild().nodeValue()) );
   
   LutElement elem( node.toElement().attribute( "index", "-1" ).toUInt(),
-		   node.toElement().attribute( "label", "Unknown" ) );
+		   node.toElement().attribute( "label", "Unknown" ).toUtf8().constData() );
   switch( colours.size() )
     {
     case 3:
@@ -285,15 +285,15 @@ LutElement readColourNode( QDomNode &node )
 void FileManager::readLMLFile(const std::string& filename, LookUpTable* lut)
 {
     // read the XML file and create DOM tree
-    QFile opmlFile( filename );
+    QFile opmlFile( filename.c_str() );
     if ( !opmlFile.open( IO_ReadOnly ) )
-      throw std::ios::failure( QObject::tr("FileManager", "Cannot open file %1").arg(filename) );
+      throw std::ios::failure( QObject::tr("FileManager", "Cannot open file %1").arg(filename.c_str()).toUtf8().constData() );
 
     QString errorMsg, errorLine;
     QDomDocument domTree;
     if ( !domTree.setContent( &opmlFile, &errorMsg, &errorLine ) ) {
       opmlFile.close();
-      throw std::ios::failure( QObject::tr("FileManager", "Parsing error for file %1\n%2\nLine:%3").arg(filename).arg(errorMsg).arg(errorLine) );
+      throw std::ios::failure( QObject::tr("FileManager", "Parsing error for file %1\n%2\nLine:%3").arg(filename.c_str()).arg(errorMsg).arg(errorLine).toUtf8().constData() );
     }
     opmlFile.close();
 
@@ -311,7 +311,7 @@ void FileManager::readLMLFile(const std::string& filename, LookUpTable* lut)
 	      QDomText textChild = currentNode.firstChild().toText();
 	      if ( !textChild.isNull() ) {
 				// Process header->name here
-		lut->setLutName(textChild.data());
+		lut->setLutName(textChild.data().toUtf8().constData());
 	      }
 	    } else if ( currentNode.nodeName() == "type" ) {
 	      QDomText textChild = currentNode.firstChild().toText();
@@ -336,7 +336,7 @@ void FileManager::readLMLFile(const std::string& filename, LookUpTable* lut)
 	  if ( currentNode.isElement() ) {
             if ( currentNode.nodeName() == "label" ) {
 	      int n    = currentNode.toElement().attribute( "index" ).toInt();
-	      string l = currentNode.firstChild().toText().data();
+	      string l = currentNode.firstChild().toText().data().toUtf8().constData();
 	      cout << n << " " << l << endl;
 	      lut->setVolumeName(n, l);
             }
@@ -367,7 +367,7 @@ Image::Handle readImage(const string& atlasdir, QDomNode& imagesNode, const stri
   string filename;
 
   while ( !node.isNull() ) {
-    if ( node.isElement() && node.nodeName() == tag ) {
+    if ( node.isElement() && node.nodeName() == tag.c_str() ) {
       QDomText textChild = node.firstChild().toText();
       if ( !textChild.isNull() )
 	filename = string(textChild.data().ascii());
@@ -382,17 +382,17 @@ Atlas::Handle FileManager::readXMLAtlas(const string& atlasdir,
 					const string& filename)
 {
   string fullpath(atlasdir + "/" + filename);
-  QFile opmlFile( fullpath );
+  QFile opmlFile( fullpath.c_str() );
   if ( !opmlFile.open( IO_ReadOnly ) )
     throw 
-      std::ios::failure( QObject::tr("Couldn't open file %1").arg(fullpath) );
+      std::ios::failure( QObject::tr("Couldn't open file %1").arg(fullpath.c_str()).toUtf8().constData() );
   QString errorMsg, errorLine;
   QDomDocument domTree;
   if ( !domTree.setContent( &opmlFile, &errorMsg, &errorLine ) ) {
     opmlFile.close();
     throw 
       std::ios::failure( QObject::tr("Parsing error for file %1\n%2\nLine:%3")
-			 .arg(filename).arg(errorMsg).arg(errorLine) );
+			 .arg(filename.c_str()).arg(errorMsg).arg(errorLine).toUtf8().constData() );
   }
   opmlFile.close();
 
@@ -459,13 +459,13 @@ Atlas::Handle FileManager::readXMLAtlas(const string& atlasdir,
 	if ( currentNode.isElement() ) {
 	  if ( currentNode.nodeName() == "label" ) {
 	    int n    = currentNode.toElement().attribute( "index" ).toInt();
-	    string l = currentNode.firstChild().toText().data();
+	    string l = currentNode.firstChild().toText().data().toUtf8().constData();
 	    atlas->addLabel(n, l);
 	    int x = currentNode.toElement().attribute( "x", "0" ).toInt();
 	    int y = currentNode.toElement().attribute( "y", "0" ).toInt();
 	    int z = currentNode.toElement().attribute( "z", "0" ).toInt();
 	    int v = currentNode.toElement().attribute( "v", "0" ).toInt();
-	    string ref = currentNode.toElement().attribute( "ref", "" );
+	    string ref = currentNode.toElement().attribute( "ref", "" ).toUtf8().constData();
 	    atlas->addCentre(n, x, y, z, v);
 	    //atlas->addReference(n, ref);
 	  }
@@ -490,12 +490,12 @@ bool FileManager::checkFileExists(const std::string& path)
 
 vector<string> FileManager::getFilenames(const std::string& path, const std::string& glob)
 {
-  QDir d(path, glob);
+  QDir d(path.c_str(), glob.c_str());
 
   vector<string> result;
 
   for(unsigned int i = 0; i < d.count(); ++i)
-    result.push_back(d[i]);
+    result.push_back(d[i].toUtf8().constData());
 
   return  result;
 }
