@@ -33,7 +33,7 @@ public:
   double inqRange(){return m_range;}
 
 protected:
-  Handle countedThis() const { return Handle(m_countedThis); }
+  Handle countedThis() const { return m_countedThis.lock(); }
 
 private:
   GraphManager();
