@@ -7,8 +7,10 @@
 #include <qspinbox.h>
 
 HistogramOptionsDialogImpl::HistogramOptionsDialogImpl(QWidget *parent, HistogramOptions &options):
-  HistogramOptionsDialog(parent), m_options(options)
+  QDialog(parent), m_options(options)
 {
+  setupUi(this);
+
   minIntensity->setValidator(new QDoubleValidator(this));
   intensityRange->setChecked(m_options.inqIntensityRange());
   minIntensity->setText(tr("%1").arg(options.inqMin()));
