@@ -6,7 +6,7 @@
 
 class HistogramOptions;
 
-class HistogramOptionsDialogImpl : public HistogramOptionsDialog
+class HistogramOptionsDialogImpl : public QDialog, private Ui::HistogramOptionsDialog
 {
 public:
   HistogramOptionsDialogImpl( QWidget* parent, HistogramOptions& options );
