@@ -21,10 +21,10 @@
 //! behaviour.
 //!
 //! @author Dave Flitney
-class HistogramToolbar: public HistogramToolbarBase
+class HistogramToolbar: public QWidget, public Ui::HistogramToolbarBase
 {
 public:
-  HistogramToolbar(QWidget *parent): HistogramToolbarBase(parent) {}
+  HistogramToolbar(QWidget *parent) { setupUi(this); }
 
 private:
 };
