@@ -17,9 +17,6 @@
 
 #include "tracker.h"
 
-#include <iostream>
-using namespace std;
-
 struct ImageDisplaySetting::Implementation
 {
   Implementation(LookUpTable::Handle lut,float trans, bool visible, Image::Handle image): 
