@@ -19,7 +19,7 @@
 #include "lookuptable.h"
 #include "bricon.h"
   
-typedef enum {None,Lines,RGB} DtiDisplay;
+typedef enum {None, Lines, RGB, LinesRGB} DtiDisplay;
 
 class ImageDisplaySetting  
 {
