@@ -6,26 +6,31 @@
 
 /*  CCOPYRIGHT */
 
+// No longer in use... See LightboxWindow
+
 #include "lightboxwidget.h"
 #include "maintoolbar.h"
 
-#include <qscrollview.h>
+#include <q3scrollview.h>
 #include <qpixmap.h>
 #include <qcheckbox.h>
 #include <qtoolbutton.h>
 #include <qlayout.h>
+//Added by qt3to4:
+#include <QResizeEvent>
 
 #include "tracker.h"
 
 #include "lightbox.xpm"
 
-LightboxWidget::LightboxWidget(QWidget *parent,ImageGroup::Handle i,OverlayList::Handle ol, Cursor::Handle& c ) :  
-  ImageWidget(parent,i,ol,c), m_image(i), m_zoom(1.0)
+LightboxWidget::LightboxWidget(QWidget *parent, ImageGroup::Handle i,OverlayList::Handle ol, Cursor::Handle& c )
+  : ImageWidget(parent, i, ol, c), m_image(i), m_zoom(1.0)
 {
   TRACKER("LightboxWidget::LightboxWidget");
-  m_sv = new QScrollView(this);
+  m_sv = new Q3ScrollView(this);
   
   setIcon( QPixmap(lightbox_xpm) );
+  setWindowTitle("Lightbox View");
 
   setCentralWidget(m_sv);
   
@@ -107,7 +112,7 @@ void LightboxWidget::scrolled(int v)
 
 struct SlicePlacer
 {
-  SlicePlacer(QScrollView* sv, unsigned int border, float zoom):
+  SlicePlacer(Q3ScrollView* sv, unsigned int border, float zoom):
     m_sv(sv), m_borderPixels(border), m_zoom(zoom),
     m_x(border), m_y(border), 
     m_availableWidth(sv->visibleWidth()), m_heightIncrement(0),
@@ -137,7 +142,7 @@ struct SlicePlacer
   unsigned int width() const { return m_width; }
   unsigned int height() const { return m_y + m_heightIncrement; }
 
-  QScrollView* m_sv;
+  Q3ScrollView* m_sv;
   unsigned int m_borderPixels;
   float        m_zoom;
 
@@ -181,12 +186,12 @@ void LightboxWidget::repaintSlices()
 #endif
 }
 
-#include <qfiledialog.h>
+#include <q3filedialog.h>
 #include <qpixmap.h>
  
 void LightboxWidget::print()
 {
-  QString fn = QFileDialog::getSaveFileName("screenshot.png", 
+  QString fn = Q3FileDialog::getSaveFileName("screenshot.png", 
 					    "PNG files (*.png)", this,
 					    "Screenshot dialog",
 					    "Select a filename for saving");
