@@ -2,24 +2,27 @@
 
     James Saunders, David Flitney and Stephen Smith, FMRIB Image Analysis Group
 
-    Copyright (C) 2002-2003 University of Oxford  */
+    Copyright (C) 2002-2013 University of Oxford  */
 
 /*  CCOPYRIGHT */
 
+//	No longer in use.... See lightboxWindow
 #if !defined(LIGHTBOXWIDGET_H)
 #define LIGHTBOXWIDGET_H
 
 #include "imagewidget.h"
 #include "slicewidget.h"
+//Added by qt3to4:
+#include <QResizeEvent>
 
 class OverlayWidget;
-class QScrollView;
+class Q3ScrollView;
 
 class LightboxWidget : public ImageWidget  
 {
   Q_OBJECT
 public:
-  LightboxWidget(QWidget *parent,ImageGroup::Handle i,
+  LightboxWidget(QWidget *parent, ImageGroup::Handle i,
                  OverlayList::Handle ol, Cursor::Handle& c);
   virtual ~LightboxWidget();
 
@@ -42,7 +45,7 @@ private:
 
   SliceListHandle    m_slices;
   ImageGroup::Handle m_image;
-  QScrollView       *m_sv;
+  Q3ScrollView       *m_sv;
   QToolButton       *m_cursorModeButton;
   float              m_zoom;
 };
