@@ -8,8 +8,8 @@
 
 #include "lookuptable.h"
 #include "filemanager.h"
-#include <qfileinfo.h>
-#include <qcolor.h>
+#include <QtCore/qfileinfo.h>
+#include <QtGui/qcolor.h>
 
 #include <assert.h>
 #include <math.h>
@@ -49,7 +49,7 @@ LookUpTable::LookUpTable(const std::string& filename):
     FileManager::readLMLFile(filename, this);
   } else {
     if((ext != "rgb") && (ext != "lut"))
-      throw std::runtime_error("LookUpTable: lut file type unknown extension: " + fi.extension());
+      throw std::runtime_error(("LookUpTable: lut file type unknown extension: " + fi.extension()).toUtf8().constData());
 
     if(fi.extension() == "rgb")
       m_isIndexLut = true;
