@@ -16,7 +16,9 @@
 #include "application.h"
 #include "splashscreen.h"
 
-#include <qapplication.h>
+//#include <qapplication.h>
+
+#include <QSplashScreen>
 
 namespace Utilities {
 
@@ -78,8 +80,24 @@ int main( int argc, char **argv )
   options.add(help);
   options.add(mode);
 
+  Option<string> lutname(string("-l,--lut"), string("Unset"),
+			 string("Lookup table name. As per GUI, one of: Greyscale;"
+				"\n\t\t\t\"Red-Yellow\"; \"Blue-Lightblue\"; Red; Green;"
+				"\n\t\t\tBlue; Yellow; Pink; Hot; Cool; Copper, etc."), 
+			 false, requires_argument);
+  Option<float> transparency(string("-t,--trans"), float(0.0), 
+			     string("Initial transparency, e.g., 0.2"), 
+			     false, requires_argument);
+  Option< std::pair<float,float> > ibricon(string("-b,--bricon"), std::pair<float,float>(0.0,0.0), 
+					   string("Initial bricon range, e.g., 2.3,6"), 
+					   false, requires_argument);
+  
   OptionParser imageOptions("Per-image options", "image [-l GreyScale] [-t 0.1] [-b 2.3,6]");
   
+  imageOptions.add(lutname);
+  imageOptions.add(ibricon);
+  imageOptions.add(transparency);
+  
   try {
     QApplication::setColorSpec( QApplication::CustomColor );
     QApplication app(argc,argv);			
@@ -88,31 +106,14 @@ int main( int argc, char **argv )
     ApplicationOptions appOpts;
 
     for(unsigned int pos = options.parse_command_line(qApp->argc(), qApp->argv());
-	int(pos) < qApp->argc(); ) {
-      Option<string> lutname(string("-l,--lut"), string("Unset"),
-			     string("Lookup table name. As per GUI, one of: Greyscale;"
-				    "\n\t\t\t\"Red-Yellow\"; \"Blue-Lightblue\"; Red; Green;"
-				    "\n\t\t\tBlue; Yellow; Pink; Hot; Cool; Copper, etc."), 
-			     false, requires_argument);
-      Option<float> transparency(string("-t,--trans"), float(0.0), 
-				 string("Initial transparency, e.g., 0.2"), 
-				 false, requires_argument);
-      Option< std::pair<float,float> > ibricon(string("-b,--bricon"), std::pair<float,float>(0.0,0.0), 
-					       string("Initial bricon range, e.g., 2.3,6"), 
-					       false, requires_argument);
-  
-  
-      imageOptions.add(lutname);
-      imageOptions.add(ibricon);
-      imageOptions.add(transparency);
-
+		int(pos) < qApp->argc(); ) {
       // Should be an image name followed by image sub options
       string filename(qApp->argv()[pos]);
 
       pos += imageOptions.parse_command_line(qApp->argc() - pos, &(qApp->argv()[pos]));
 
       if(!imageOptions.check_compulsory_arguments())
-	imageOptions.usage();
+		imageOptions.usage();
 
       appOpts.push_back(OverlayOption(filename, lutname, transparency, ibricon));
     }
@@ -121,24 +122,6 @@ int main( int argc, char **argv )
       appOpts.setModes(mode.value());
     }
 
-    // Dummy - unused - options needed to make help text work properly
-    Option<string> lutname(string("-l,--lut"), string("Unset"),
-			   string("Lookup table name. As per GUI, one of: Greyscale;"
-				  "\n\t\t\t\"Red-Yellow\"; \"Blue-Lightblue\"; Red; Green;"
-				  "\n\t\t\tBlue; Yellow; Pink; Hot; Cool; Copper, etc."), 
-			   false, requires_argument);
-    Option<float> transparency(string("-t,--trans"), float(0.0), 
-			       string("Initial transparency, e.g., 0.2"), 
-			       false, requires_argument);
-    Option< std::pair<float,float> > ibricon(string("-b,--bricon"), std::pair<float,float>(0.0,0.0), 
-					     string("Initial bricon range, e.g., 2.3,6"), 
-					     false, requires_argument);
-  
-  
-    imageOptions.add(lutname);
-    imageOptions.add(ibricon);
-    imageOptions.add(transparency);
-    
     if(help.value() || !options.check_compulsory_arguments()) {
       options.usage();
       imageOptions.brief_usage();
@@ -148,6 +131,10 @@ int main( int argc, char **argv )
       SplashScreen *s = new SplashScreen(0, appOpts);
       s->show();
 
+      // QPixmap pix(fslstart_xpm);
+      // QSplashScreen splash(pix);
+      // splash.showMessage("Ready");
+      
       return app.exec();
     }
 
