@@ -17,7 +17,7 @@
 #include <memory>
 #include <vector>
 
-class MeshOptionsDialog : public MeshOptionsDialogBase
+class MeshOptionsDialog : public QDialog, private Ui::MeshOptionsDialogBase
 {
 Q_OBJECT
 
