@@ -38,7 +38,7 @@ class ModelFit
 public:
   typedef boost::shared_ptr< ModelFit > Handle;
   static Handle create(const QString & featDir);
-  typedef class Exception;
+  class Exception;
 
   virtual ~ModelFit(); 
 
@@ -75,7 +75,7 @@ public:
 private:
   ModelFit(const QString & featDir); 
 
-  typedef struct Implementation;
+  struct Implementation;
   const std::auto_ptr<Implementation> m_impl;
 };
 
