@@ -9,13 +9,13 @@
 #if !defined(MODETOOLBAR_H)
 #define MODETOOLBAR_H
 
-#include <qtoolbutton.h>
+#include <QToolButton>
 #include <string>
 
 #include "slicewidget.h"
 #include "modetoolbarbase.h"
 
-class ModeToolBarWidget : public ModeToolbarBase
+class ModeToolBarWidget : public QWidget, private Ui::ModeToolbarBase
 {
   Q_OBJECT
 
@@ -26,12 +26,12 @@ public:
   void enableMovieMode(bool on)     { m_movieModeButton->setEnabled(on);   }
   void enableSliceRollMode(bool on) { m_sliceRollButton->setEnabled(on);   }
   void enableSwitchViews(bool on)   { m_switchViewsButton->setEnabled(on); }
-  bool inqMovieMode() { return m_movieModeButton->isOn(); }
+  bool inqMovieMode()               { return m_movieModeButton->isOn(); }
   void setSwitchHelpText(const std::string&);
 
 signals:
-  void sliceRollStateChanged(int);
-  void movieStateChanged(int);
+  void sliceRollStateChanged(bool);
+  void movieStateChanged(bool);
   void switchViewsClicked();
   void optionsClicked();
   void printClicked();
