@@ -32,115 +32,88 @@ using namespace std;
 
 OrthoWidget::OrthoWidget(QWidget *parent, ImageGroup::Handle& i,
                          OverlayList::Handle ol, Cursor::Handle& c): 
-  ImageWidget(parent, i, ol, c), m_image(i), m_layout(Traditional)
+  ImageWindow(i, ol, c, parent), m_image(i), m_layout(Traditional)
 {
   TRACKER("OrthoWidget::OrthoWidget(QWidget *, Cursor*, ImageGroup::Handle&)");
 
-  m_centralWidget = new QWidget(this); 
-
-  m_grid = new QGridLayout(m_centralWidget, 2, 2, 6, -1);
-  m_centralWidget->setBackgroundColor(QColor(128, 128, 128));
+//  m_centralWidget = new QWidget();
+//
+//  m_grid = new QGridLayout(m_centralWidget, 2, 2, 6, -1);
+  //  m_centralWidget->setBackgroundColor(QColor(10,10,10));
 
   setIcon( QPixmap(ortho_xpm) );
-
+  setWindowTitle("Orthographic View");
   //m_overlayList->attach(this);
 
   //m_slices = SliceListHandle(new SliceList);
- 
-
-//   SliceWidget::Handle m_coronal = 
-//     SliceWidget::Handle(new CoronalWidget(m_centralWidget, "coronal", m_cursor,
-// 					  m_overlayList, m_drawSettings, m_undoList));
-
-//   SliceWidget::Handle m_axial = 
-//     SliceWidget::Handle(new AxialWidget(m_centralWidget, "axial", m_cursor, 
-// 					m_overlayList, m_drawSettings, m_undoList));
-
-//   SliceWidget::Handle m_sagittal = 
-//     SliceWidget::Handle(new SagittalWidget(m_centralWidget, "sagittal", m_cursor, 
-// 					   m_overlayList, m_drawSettings, m_undoList));
 
   m_coronal  = new SliceView(m_centralWidget, "corornal");
   m_axial    = new SliceView(m_centralWidget, "axial");
   m_sagittal = new SliceView(m_centralWidget, "sagittal");
+  setLayout(m_layout);
+
+  SliceWidget* coronal =  new CoronalWidget(m_coronal, "coronal", getCursor(),
+		  getOverlayList(), getDrawSettings(), m_undoList, getOpts());
+
+  SliceWidget* axial =    new AxialWidget(m_axial, "axial", getCursor(),
+		  getOverlayList(), getDrawSettings(), m_undoList, getOpts());
+
+  SliceWidget* sagittal = new SagittalWidget(m_sagittal, "sagittal", getCursor(),
+		  getOverlayList(), getDrawSettings(), m_undoList, getOpts());
 
-  SliceWidget* coronal =  new CoronalWidget(m_coronal, "coronal", m_cursor,
-					    m_overlayList, m_drawSettings, m_undoList, m_opts);
-  
-  SliceWidget* axial =    new AxialWidget(m_axial, "axial", m_cursor, 
-					  m_overlayList, m_drawSettings, m_undoList, m_opts);
-  
-  SliceWidget* sagittal = new SagittalWidget(m_sagittal, "sagittal", m_cursor, 
-					     m_overlayList, m_drawSettings, m_undoList, m_opts);
   m_coronal->setSliceWidget(coronal);
   m_axial->setSliceWidget(axial);
   m_sagittal->setSliceWidget(sagittal);
 
   ImageInfo::Handle info(m_image->getMainImage()->getInfo());
 
-  setLayout();
 
-  connect(this,           SIGNAL(modeChanged(SliceWidget::Mode)), 
-	  coronal,  SLOT(setMode(SliceWidget::Mode)));
-  connect(this,           SIGNAL(modeChanged(SliceWidget::Mode)), 
-	  sagittal, SLOT(setMode(SliceWidget::Mode)));
-  connect(this,           SIGNAL(modeChanged(SliceWidget::Mode)),
-	  axial,    SLOT(setMode(SliceWidget::Mode)));
+  connect(this,     SIGNAL(modeChanged(SliceWidget::Mode)),
+		  coronal,  SLOT(setMode(SliceWidget::Mode)));
+  connect(this,     SIGNAL(modeChanged(SliceWidget::Mode)),
+		  sagittal, SLOT(setMode(SliceWidget::Mode)));
+  connect(this,     SIGNAL(modeChanged(SliceWidget::Mode)),
+		  axial,    SLOT(setMode(SliceWidget::Mode)));
 
-  connect(this, SIGNAL(zoomValueChanged(int)), coronal, SLOT(setZoom(int)));
-  connect(this, SIGNAL(zoomValueChanged(int)), sagittal,SLOT(setZoom(int)));
-  connect(this, SIGNAL(zoomValueChanged(int)), axial,   SLOT(setZoom(int)));
- 
+  // Add a zoom control and connect it to the slice widgets
+  QSpinBox *zoomControl = new QSpinBox(this);
+  zoomControl->setMaximum(1000);
+  zoomControl->setMinimum(25);
+  zoomControl->setValue(100);
+  m_mainToolBar->insertWidget(actionCursorMode, zoomControl);
   connect(this, SIGNAL(resetZoom()), coronal, SLOT(resetZoom()));
   connect(this, SIGNAL(resetZoom()), sagittal,SLOT(resetZoom()));
   connect(this, SIGNAL(resetZoom()), axial,   SLOT(resetZoom()));
-  
-  connect(coronal,  SIGNAL(message(const QString&, int )), SIGNAL(message(const QString&, int )));
-  connect(sagittal, SIGNAL(message(const QString&, int )), SIGNAL(message(const QString&, int )));
-  connect(axial,    SIGNAL(message(const QString&, int )), SIGNAL(message(const QString&, int )));
 
+  connect(zoomControl, SIGNAL( valueChanged(int) ), coronal,  SLOT( setZoom(int) ));
+  connect(zoomControl, SIGNAL( valueChanged(int) ), sagittal, SLOT( setZoom(int) ));
+  connect(zoomControl, SIGNAL( valueChanged(int) ), axial,    SLOT( setZoom(int) ));
+//
+//  connect(coronal,  SIGNAL(message(const QString&, int )), SIGNAL(message(const QString&, int )));
+//  connect(sagittal, SIGNAL(message(const QString&, int )), SIGNAL(message(const QString&, int )));
+//  connect(axial,    SIGNAL(message(const QString&, int )), SIGNAL(message(const QString&, int )));
+//
   connect(this, SIGNAL(crossHairModeChanged(bool)), coronal,  SLOT(crossHairMode(bool)));
   connect(this, SIGNAL(crossHairModeChanged(bool)), sagittal, SLOT(crossHairMode(bool)));
   connect(this, SIGNAL(crossHairModeChanged(bool)), axial,    SLOT(crossHairMode(bool)));
-
-  connect(coronal, SIGNAL(emitZoomFactor(int)), SLOT(setZoomValue(int)));
-  connect(sagittal,SIGNAL(emitZoomFactor(int)), SLOT(setZoomValue(int)));
-  connect(axial,   SIGNAL(emitZoomFactor(int)), SLOT(setZoomValue(int)));
-
-  m_modeWidget->enableSwitchViews(true);
-  m_modeWidget->setSwitchHelpText("Switch View<hr>Toggles between different layouts.");
-  connect(m_modeWidget, SIGNAL(switchViewsClicked()), SLOT(changeView()));
+//
+//  connect(coronal, SIGNAL(emitZoomFactor(int)), SLOT(setZoomValue(int)));
+//  connect(sagittal,SIGNAL(emitZoomFactor(int)), SLOT(setZoomValue(int)));
+//  connect(axial,   SIGNAL(emitZoomFactor(int)), SLOT(setZoomValue(int)));
 
   //m_cursor->attach(this);
 
   //std::for_each(m_slices->begin(), m_slices->end(), SetImageCursor(m_cursor));
 
-  setLabels(m_overlayList.get());
+  setLabels(getOverlayList().get());
 
-  setCentralWidget(m_centralWidget);
+//  setCentralWidget(m_centralWidget);
 }
 
 OrthoWidget::~OrthoWidget()
 {
   TRACKER("OrthoWidget::~OrthoWidget");  
-  m_cursor->detach(this);
-}
-
-std::string axisCodeToString(int code, bool lower)
-{
-  std::string s;
-  switch(code)
-    {
-    case NIFTI_L2R: lower ? s = "L" : s = "R"; break;
-    case NIFTI_R2L: lower ? s = "R" : s = "L"; break;
-    case NIFTI_P2A: lower ? s = "P" : s = "A"; break;
-    case NIFTI_A2P: lower ? s = "A" : s = "P"; break;
-    case NIFTI_I2S: lower ? s = "I" : s = "S"; break;
-    case NIFTI_S2I: lower ? s = "S" : s = "I"; break;
-    default: s = ""; break;
-    }
-
-  return s;
+//  m_cursor->detach(this);
 }
 
 void OrthoWidget::print()
@@ -178,49 +151,59 @@ void OrthoWidget::print()
     }
 }
 
+
 void OrthoWidget::update(const OverlayList* o, OverlayListMsg msg)
 {
-  ImageWidget::update(o, msg);
+  ImageWindow::update(o, msg);
 
   setLabels(o);
 }
 
-void OrthoWidget::setLayout()
+void OrthoWidget::setLayout(Layout l)
 {
-  if(m_grid)
-    delete m_grid;
-  switch(m_layout)
+	m_layout = l;
+
+	m_grid->removeWidget(m_coronal);
+	m_grid->removeWidget(m_sagittal);
+	m_grid->removeWidget(m_axial);
+
+	switch(m_layout)
     {
     case Traditional:
-      m_grid = new QGridLayout(m_centralWidget, 2, 2, 6, -1);
-      m_grid->addWidget(m_coronal,  0, 0);
-      m_grid->addWidget(m_sagittal, 0, 1);
-      m_grid->addWidget(m_axial,    1, 0);
-      break;
+		m_grid->addWidget(m_coronal,  0, 0);
+		m_grid->addWidget(m_sagittal, 0, 1);
+		m_grid->addWidget(m_axial,    1, 0);
+		break;
     case InRow:
-      m_grid = new QGridLayout(m_centralWidget, 1, 3, 6, -1);
-      m_grid->addWidget(m_sagittal,  0, 0);
-      m_grid->addWidget(m_coronal, 0, 1);
-      m_grid->addWidget(m_axial,    0, 2);
-      break;
+		m_grid->addWidget(m_sagittal, 0, 0);
+		m_grid->addWidget(m_coronal,  0, 1);
+		m_grid->addWidget(m_axial,    0, 2);
+		break;
     case InColumn:
-      m_grid = new QGridLayout(m_centralWidget, 3, 1, 6, -1);
-      m_grid->addWidget(m_sagittal,  0, 0);
-      m_grid->addWidget(m_coronal, 1, 0);
-      m_grid->addWidget(m_axial,    2, 0);
-      break;
+		m_grid->addWidget(m_sagittal, 0, 0);
+		m_grid->addWidget(m_coronal,  1, 0);
+		m_grid->addWidget(m_axial,    2, 0);
+		break;
     default:
-      break;
+		break;
     }
-  m_grid->activate();
+
+	m_grid->activate();
 }
 
-void OrthoWidget::changeView()
+void OrthoWidget::on_actionSwitchViews_triggered()
 {
   m_layout = Layout( (m_layout+1) % (InColumn+1) );
-  setLayout();
+
+  setLayout(m_layout);
 }
 
+//void OrthoWidget::changeView()
+//{
+//  m_layout = Layout( (m_layout+1) % (InColumn+1) );
+//  setLayout();
+//}
+
 void OrthoWidget::setLabels(const OverlayList* o)
 {
   // coronal=ik
@@ -248,7 +231,7 @@ void OrthoWidget::setLabels(const OverlayList* o)
   m_coronal->setNorthText(axisCodeToString(kcode, false));
   m_coronal->setSouthText(axisCodeToString(kcode, true));
 
-  if(m_opts.inqShowLabels()) {
+  if(getOpts().inqShowLabels()) {
     if(i->hasValidXfms() ) {
       m_sagittal->setLabelsState(SliceView::Enabled);
       m_coronal->setLabelsState(SliceView::Enabled);
