@@ -9,7 +9,7 @@
 #if !defined(ORTHOWIDGET_H)
 #define ORTHOWIDGET_H
 
-#include "imagewidget.h"
+#include "imagewindow.h"
 #include "slicewidget.h"
 #include "sliceview.h"
 #include "overlaylist.h"
@@ -19,11 +19,11 @@ class QGridLayout;
 class QTimer;
 class QWidget;
 
-class OrthoWidget : public ImageWidget
+class OrthoWidget : public ImageWindow
 {
   Q_OBJECT
 public:
-  typedef enum {Traditional=0, InRow, InColumn} Layout;
+  typedef enum {Traditional = 0, InRow, InColumn} Layout;
 
   OrthoWidget(QWidget *parent, ImageGroup::Handle& i, 
               OverlayList::Handle ol, Cursor::Handle& c );
@@ -31,25 +31,31 @@ public:
  
   void update(const OverlayList*, OverlayListMsg);
 
+//  virtual OverlayList::Handle getOverlayList(void) { return m_overlayList; }
+
 signals:
   void  volChanged(int n);
 
 public slots:
-  void changeView();
+//  void changeView();
   void print();
 
+private slots:
+  virtual void on_actionSwitchViews_triggered();
+
 private:
   void setLabels(const OverlayList*);
-  void setLayout();
+
+  virtual void setLayout(Layout);
 
   QTimer            *m_timer;
   //SliceListHandle    m_slices;
   SliceView         *m_coronal;
   SliceView         *m_sagittal;
   SliceView         *m_axial;
-  QGridLayout       *m_grid; 
+  //QGridLayout       *m_grid;
   ImageGroup::Handle m_image;
-  QWidget           *m_centralWidget;
+  //QWidget           *m_centralWidget;
   Layout             m_layout;
 };
 
