@@ -12,12 +12,13 @@
 #include "overlaylist.h"
 #include "overlayinfodialogbase.h"
 
-class OverlayInfoDialog : public OverlayInfoDialogBase, OverlayListObserver
+class OverlayInfoDialog : public QDialog, private Ui_OverlayInfoDialogBase, 
+  public OverlayListObserver
 {
 Q_OBJECT
 
 public:
-  OverlayInfoDialog(QWidget* w,OverlayList::Handle l,ImageGroup::Handle i);
+  OverlayInfoDialog(QWidget* w, OverlayList::Handle l, ImageGroup::Handle i);
   virtual ~OverlayInfoDialog();
   void update(const OverlayList* l, OverlayListMsg msg);
 
@@ -44,8 +45,8 @@ protected slots:
 
 signals: 
 
-   virtual void openLookUpTable();
-   virtual void message(const QString&, int);
+   void openLookUpTable();
+   void message(const QString&, int);
 };
 
 
