@@ -11,13 +11,15 @@
 #include <qapplication.h>
 #include <qlayout.h>
 #include <qcheckbox.h>
-#include <qlistview.h>
+#include <q3listview.h>
 #include <qslider.h>
 #include <qtoolbutton.h>
 #include <qobject.h>
-#include <qheader.h>
+#include <q3header.h>
 #include <qlabel.h>
 #include <qtooltip.h>
+//Added by qt3to4:
+#include <QPixmap>
 
 #include "tracker.h"
 
@@ -42,11 +44,11 @@ const char * upButtonText = "Move overlay up.<br><hr>Moves the currently selecte
 
 const char * downButtonText = "Move overlay down.<br><hr>Moves the currently selected overlay so that it appears below other overlays.";
 
-class LayerListItem : public QListViewItem
+class LayerListItem : public Q3ListViewItem
 {
 public:
-  LayerListItem(QListView* parent, const  MetaImage::Handle mi):
-    QListViewItem(parent),
+  LayerListItem(Q3ListView* parent, const  MetaImage::Handle mi):
+    Q3ListViewItem(parent),
     m_mi(mi)
   {
     refresh();
@@ -86,11 +88,11 @@ private:
 
 class InsertLayerItem {
 public:
-  InsertLayerItem(QListView* lv) : m_lv(lv) {}
+  InsertLayerItem(Q3ListView* lv) : m_lv(lv) {}
   void operator()(MetaImage::Handle mi);
 
 private:
-  QListView* m_lv;
+  Q3ListView* m_lv;
 };
 
 void InsertLayerItem::operator()(MetaImage::Handle mi) 
@@ -99,9 +101,13 @@ void InsertLayerItem::operator()(MetaImage::Handle mi)
 }
 
 OverlayWidget::OverlayWidget(QWidget* w, OverlayList::Handle l):
-  OverlayWidgetBase(w, 0), m_overlayList(l), m_blockEvents(false), m_blockSliderUpdate(false)
+  QDockWidget(w),
+  m_overlayList(l), m_blockEvents(false), m_blockSliderUpdate(false)
 {
   TRACKER("OverlayWidget::OverlayWidget(QWidget* w, OverlayList::Handle l)");
+
+  setupUi(this);
+
   m_overlayList->attach(this);
 
   m_transSlider->setMinValue(0);
@@ -122,12 +128,12 @@ OverlayWidget::OverlayWidget(QWidget* w, OverlayList::Handle l):
 
   connect(m_upButton, SIGNAL(pressed()), this, SLOT(upButtonPressed()));
   connect(m_downButton, SIGNAL(pressed()), this, SLOT(downButtonPressed()));
-  connect(m_detailsButton, SIGNAL(pressed()), this, SLOT(detailsButtonPressed()));
+//  connect(detailsButton, SIGNAL(pressed()), this, SLOT(detailsButtonPressed()));
 
   connect(m_overlayListView,SIGNAL(selectionChanged()),          
           this ,SLOT(listSelectChanged()));
-  connect(m_overlayListView,SIGNAL(doubleClicked(QListViewItem*)),
-        this,SLOT(listDoubleClicked(QListViewItem*)));
+  connect(m_overlayListView,SIGNAL(doubleClicked(Q3ListViewItem*)),
+        this,SLOT(listDoubleClicked(Q3ListViewItem*)));
 
   connect(m_visibleButton,SIGNAL(toggled(bool)),
         this,SLOT(visibleButtonChanged(bool)));  
@@ -144,7 +150,7 @@ OverlayWidget::OverlayWidget(QWidget* w, OverlayList::Handle l):
 
   QToolTip::add(m_visibleButton,tr(toggleVisibiltyText));  
   QToolTip::add(m_lockedButton, tr(toggleLockText));
-  QToolTip::add(m_detailsButton,  tr(infoButtonText));
+  QToolTip::add(detailsButton,  tr(infoButtonText));
   QToolTip::add(m_upButton,     tr(upButtonText));
   QToolTip::add(m_downButton,   tr(downButtonText));
   QToolTip::add(m_transSlider,  tr(transparencySliderText));
@@ -189,7 +195,7 @@ void OverlayWidget::updateListView()
                 m_overlayList->end(),
                 InsertLayerItem(m_overlayListView));
   
-  QListViewItem* curItem = getLayerItem(m_overlayList->getActiveMetaImage());
+  Q3ListViewItem* curItem = getLayerItem(m_overlayList->getActiveMetaImage());
 
   if(curItem)
     m_overlayListView->setSelected(curItem, true);
@@ -242,12 +248,12 @@ void OverlayWidget::listSelectChanged()
   }
 }
 
-QListViewItem* OverlayWidget::getLayerItem(const MetaImage::Handle mi) const
+Q3ListViewItem* OverlayWidget::getLayerItem(const MetaImage::Handle mi) const
 {
   TRACKER("OverlayWidget::getLayerItem(const MetaImage::Handle mi)");
   bool success(false);
-  QListViewItem* itemFound = NULL;
-  QListViewItemIterator it( m_overlayListView );
+  Q3ListViewItem* itemFound = NULL;
+  Q3ListViewItemIterator it( m_overlayListView );
     
   while(it.current() && !success)   
   {
@@ -297,7 +303,7 @@ void OverlayWidget::lockedButtonChanged(bool state)
   m_overlayList->setReadOnly(state);
 }
 
-void OverlayWidget::listDoubleClicked(QListViewItem* item)
+void OverlayWidget::listDoubleClicked(Q3ListViewItem* item)
 {
   TRACKER("OverlayWidget::listDoubleClicked(QListViewItem* item)");
   if(m_blockEvents) return; 
@@ -382,8 +388,8 @@ void OverlayWidget::updateControls()
          }
 }
 
-void OverlayWidget::detailsButtonPressed()
+void OverlayWidget::on_detailsButton_pressed()
 {
-  TRACKER("OverlayWidget::detailsButtonPressed()");
+  TRACKER("OverlayWidget::on_detailsButton_pressed()");
   emit infoButtonAction();
 }
