@@ -16,30 +16,64 @@
 #include <stdlib.h>
 #include <iostream>
 
-#include <qvariant.h>
+#include <QtCore/QVariant>
 
 using namespace std;
 
-Preferences::Preferences()
+struct Preferences::Implementation
 {
-  setPath("fmrib.ox.ac.uk", "fslview", User);
-}
+  Implementation() : m_assistantpath(""), m_atlaspath(""), 
+		     m_fsldir(""), m_mni(""), m_w(0), m_h(0), m_x(0), m_y(0)
+  {
+  }
+  
+  string m_assistantpath;
+  string m_atlaspath;
+  string m_fsldir;
+  string m_mni;
+  int m_w, m_h, m_x, m_y;
+};
 
-string Preferences::inqAtlasPath() const
+Preferences::Handle Preferences::m_instance;
+
+Preferences::Preferences(): m_impl(new Preferences::Implementation())
 {
   bool ok;
-  if(m_atlaspath == "") {
+  setPath("fmrib.ox.ac.uk", "fslview", QSettings::UserScope);
+
+  if(m_impl->m_atlaspath == "") {
     QStringList l = readListEntry("/fsl/atlaspath", &ok);
     if(ok)
-      m_atlaspath = l.join(":").ascii();
+      m_impl->m_atlaspath = l.join(":").ascii();
   }
+}
 
-  if(m_atlaspath == "")
-    m_atlaspath = string(getenv("FSLATLASPATH") ? 
-			 getenv("FSLATLASPATH") :
-			 inqFSLDir() + "/data/atlases");
+//! @brief Access Preferences singleton
+//!
+//! @return a handle to be used as a pointer to a Preferences object
+Preferences::Handle Preferences::getInstance()
+{
+  if(!m_instance)
+    m_instance = Preferences::Handle(new Preferences());
 
-  return m_atlaspath;
+  return m_instance;
+}
+
+string Preferences::inqAtlasPath()
+{
+  // bool ok;
+  // if(m_impl->m_atlaspath == "") {
+  //   QStringList l = readListEntry("/fsl/atlaspath", &ok);
+  //   if(ok)
+  //     m_impl->m_atlaspath = l.join(":").ascii();
+  // }
+
+  if(m_impl->m_atlaspath == "")
+    m_impl->m_atlaspath = string(getenv("FSLATLASPATH") ? 
+				 getenv("FSLATLASPATH") :
+				 inqFSLDir() + "/data/atlases");
+
+  return m_impl->m_atlaspath;
 }
 
 //! @brief Prefered value for window geometry
@@ -51,7 +85,7 @@ string Preferences::inqAtlasPath() const
 //! @param dh height of desktop
 //!
 //! @return QRect The require geometry
-QRect Preferences::inqGeometry(int dw, int dh) const
+QRect Preferences::inqGeometry(int dw, int dh)
 {
   QRect result;
     
@@ -89,7 +123,7 @@ void Preferences::setGeometry(const QRect& r)
 //! Returns vector of the prefered values of FSLATLASPATH or FSLDIR/lib/atlases
 //!
 //! @return The locations to look for atlas data sets
-vector<string> Preferences::inqAtlasPathElements() const
+vector<string> Preferences::inqAtlasPathElements()
 {
   vector<string> result;
   string delimiters(":");
@@ -113,14 +147,14 @@ vector<string> Preferences::inqAtlasPathElements() const
 //! Returns the prefered value of FSLDIR
 //!
 //! @return The users prefered value of FSLDIR
-string Preferences::inqFSLDir() const 
+string Preferences::inqFSLDir()
 {
-  if(m_fsldir == "")
-    m_fsldir = readEntry("/fsl/fsldir", "").ascii();
-  if(m_fsldir == "")
-    m_fsldir = string(getenv("FSLDIR") ? getenv("FSLDIR") : "/usr/local/fsl");
+  if(m_impl->m_fsldir == "")
+    m_impl->m_fsldir = readEntry("/fsl/fsldir", "").ascii();
+  if(m_impl->m_fsldir == "")
+    m_impl->m_fsldir = string(getenv("FSLDIR") ? getenv("FSLDIR") : "/usr/local/fsl");
 
-  return m_fsldir; 
+  return m_impl->m_fsldir; 
 }
 
 //! @brief Prefered location of MNI152 T1 brain
@@ -128,51 +162,51 @@ string Preferences::inqFSLDir() const
 //! Returns the prefered location where we can find MNI152 T1 brain image
 //!
 //! @return The users prefered location for the MNI152 T1 brain image
-string Preferences::inqMni152() const
+string Preferences::inqMni152()
 {
-  if(m_mni == "")
-    m_mni = readEntry("/fsl/mni","").ascii();
-  if(m_mni == "")
-    m_mni = inqFSLDir() + "/data/standard/MNI152_T1_2mm_brain.nii.gz";
+  if(m_impl->m_mni == "")
+    m_impl->m_mni = readEntry("/fsl/mni","").ascii();
+  if(m_impl->m_mni == "")
+    m_impl->m_mni = inqFSLDir() + "/data/standard/MNI152_T1_2mm_brain.nii.gz";
 
-  return m_mni;
+  return m_impl->m_mni;
 }
 
-string Preferences::inqAssistantPath() const
+string Preferences::inqAssistantPath()
 {
-  if(m_assistantpath == "")
-    m_assistantpath = readEntry("/qt/assistantpath","").ascii();
-  if(m_assistantpath == "")
-    m_assistantpath = string(getenv("FSLQTASSISTANTPATH") ? 
-			     getenv("FSLQTASSISTANTPATH") : "");
-  if(m_assistantpath == "")
-    m_assistantpath = string(getenv("QTDIR") ? 
-			     string(getenv("QTDIR")) + "/bin" : 
-			     inqFSLDir() + "/bin");
+  if(m_impl->m_assistantpath == "")
+    m_impl->m_assistantpath = readEntry("/qt/assistantpath","").ascii();
+  if(m_impl->m_assistantpath == "")
+    m_impl->m_assistantpath = string(getenv("FSLQTASSISTANTPATH") ? 
+				     getenv("FSLQTASSISTANTPATH") : "");
+  if(m_impl->m_assistantpath == "")
+    m_impl->m_assistantpath = string(getenv("QTDIR") ? 
+				     string(getenv("QTDIR")) + "/bin" : 
+				     inqFSLDir() + "/bin");
   
-  return m_assistantpath;
+  return m_impl->m_assistantpath;
 }
 
 void Preferences::setFSLDir(const std::string& dir)
 {
-  m_fsldir = dir;
-  writeEntry("/fsl/fsldir", dir);
+  m_impl->m_fsldir = dir;
+  writeEntry("/fsl/fsldir", dir.c_str());
 }
 
 void Preferences::setMni152(const std::string& filename)
 {
-  m_mni = filename;
-  writeEntry("/fsl/mni", filename);
+  m_impl->m_mni = filename;
+  writeEntry("/fsl/mni", filename.c_str());
 }
 
 void Preferences::setAssistantPath(const std::string& path)
 {
-  m_assistantpath = path;
-  writeEntry("/qt/assistantpath", path);
+  m_impl->m_assistantpath = path;
+  writeEntry("/qt/assistantpath", path.c_str());
 }
 
 void Preferences::setAtlasPath(const std::string& path)
 {
-  m_atlaspath = path;
-  writeEntry("/fsl/atlaspath", QStringList::split(":", path));
+  m_impl->m_atlaspath = path;
+  writeEntry("/fsl/atlaspath", QStringList::split(":", path.c_str()));
 }
