@@ -16,19 +16,21 @@
 #include <vector>
 #include <boost/shared_ptr.hpp>
 
-#include <qsettings.h>
-#include <qrect.h>
+#include <QtCore/QSettings>
+#include <QtCore/QRect>
 
 class Preferences: public QSettings
 {
 public:
-  std::string inqFSLDir() const;
-  std::string inqMni152() const;
-  std::string inqAssistantPath() const;
-  std::string inqAtlasPath() const;
-  QRect inqGeometry(int, int) const;
+  typedef boost::shared_ptr<Preferences> Handle;
 
-  std::vector<std::string> inqAtlasPathElements() const;
+  std::string inqFSLDir();
+  std::string inqMni152();
+  std::string inqAssistantPath();
+  std::string inqAtlasPath();
+  QRect inqGeometry(int, int);
+
+  std::vector<std::string> inqAtlasPathElements();
 
   void setFSLDir(const std::string&);
   void setMni152(const std::string&);
@@ -36,14 +38,14 @@ public:
   void setAtlasPath(const std::string&);
   void setGeometry(const QRect&);
 
-  Preferences();
-  virtual ~Preferences() {}
-private:
+  static Handle getInstance();
 
-  mutable std::string m_assistantpath;
-  mutable std::string m_atlaspath;
-  mutable std::string m_fsldir;
-  mutable std::string m_mni;
-  int m_w, m_h, m_x, m_y;
+private:
+  Preferences();
+
+  static Handle m_instance;
+
+  struct Implementation;  
+  const std::auto_ptr< Implementation > m_impl;
 };
 
