@@ -5,7 +5,7 @@
 
 #include "propertiesdialog.h"
 
-class PropertiesDialogImpl : public PropertiesDialog
+class PropertiesDialogImpl : public QDialog, private Ui::PropertiesDialog
 {
 public:
   static void getProperties(QWidget *);
