@@ -11,6 +11,8 @@
 
 #include <boost/shared_ptr.hpp>
 #include "qwt_plot.h"
+//Added by qt3to4:
+#include <QMouseEvent>
 #include "curvedatalist.h"
 #include "modelfit.h"
 #include "storage/timeseries.h"
@@ -18,9 +20,12 @@
 #include <vector>
 #include "cursor.h"
 #include <qwidget.h>
-#include "graphmanager.h"
+//#include "graphmanager.h"
 //#include "plotoptions.h"
 
+class QwtPlotMarker;
+class QwtPlotGrid;
+
 class PlotOptions
 {
 public:  
@@ -66,46 +71,51 @@ private:
   const std::auto_ptr<Implementation> m_impl;
 };
 
-class TimeSeriesDisplay: public QwtPlot
-{
-  Q_OBJECT
-public:  
-  typedef boost::shared_ptr< TimeSeriesDisplay > Handle;
-  TimeSeriesDisplay(QWidget* parent):QwtPlot(parent){};
-  virtual ~TimeSeriesDisplay(){};
-
-  virtual void redraw() = 0;
-
-  virtual void setDemean(bool) = 0;
-  virtual void setPercent(bool) = 0;
-  virtual void addTimeSeries() = 0;  
-  virtual void remTimeSeries() = 0;
-  virtual void remAllTimeSeries() = 0;
-  virtual void axisDisplay(bool) = 0;
-
-// public  slots:
-//    virtual void setEnabled(bool) = 0;
-//    virtual void axisDisplay() = 0;
-//    virtual void demeanButtonToggle(bool) = 0;
-
-};
+//class TimeSeriesPlot: public QwtPlot
+//{
+//  Q_OBJECT
+//public:
+//  typedef boost::shared_ptr< TimeSeriesPlot > Handle;
+//  TimeSeriesPlot(QWidget* parent):QwtPlot(parent){};
+//  virtual ~TimeSeriesPlot(){};
+//
+//  virtual void redraw() = 0;
+//
+//  virtual void setDemean(bool) = 0;
+//  virtual void setPercent(bool) = 0;
+//  virtual void addTimeSeries() = 0;
+//  virtual void remTimeSeries() = 0;
+//  virtual void remAllTimeSeries() = 0;
+//  virtual void axisDisplay(bool) = 0;
+//  virtual void drawMarker(const QwtDoublePoint&) = 0;
+//
+//// public  slots:
+////    virtual void setEnabled(bool) = 0;
+////    virtual void axisDisplay() = 0;
+////    virtual void demeanButtonToggle(bool) = 0;
+//
+//};
 
 
-class SingleSeriesWidget: public  TimeSeriesDisplay, CursorObserver, GraphManagerObserver, ModelFitObserver
+class SingleSeriesPlot: public QwtPlot, CursorObserver, ModelFitObserver
 {	
   Q_OBJECT
 public:
 
-  SingleSeriesWidget(QWidget *parent, Image::Handle ,
-                     Cursor::Handle,PlotOptions::Handle);
+  typedef boost::shared_ptr< SingleSeriesPlot > Handle;
 
-  SingleSeriesWidget(QWidget *parent, Image::Handle ,
-                     Cursor::Handle,GraphManager::Handle,
-                     PlotOptions::Handle);
+  SingleSeriesPlot(Image::Handle ,
+                     Cursor::Handle,PlotOptions::Handle,
+		     QWidget *parent);
+
+//  SingleSeriesPlot(Image::Handle ,
+//                     Cursor::Handle,GraphManager::Handle,
+//                     PlotOptions::Handle,
+//		     QWidget *parent);
 
   QSizePolicy sizePolicy();
 
-  virtual ~SingleSeriesWidget();
+  virtual ~SingleSeriesPlot();
   bool addTimeSeries(const TimeSeries::Handle &timeSeries, bool browse);
   void remTimeSeries(bool browse);
   bool addFeatSeries(const TimeSeries::Handle &, int index);
@@ -122,18 +132,22 @@ public:
   void setDemean(bool state) {m_demean = state;}
   void setPercent(bool state) {m_percent = state;}
   void redraw();
+  void selectNearestCurve(const QwtDoublePoint&);
+  void drawMarker(const QwtDoublePoint&);
 
   bool inqCausedCursorUpdate(){return m_causedCursorUpdate;} 
   virtual void update(const Cursor::Handle& c);
-  virtual void update(const GraphManager::Handle& c);
   virtual void update(ModelFit *m);
 
 private:
   CurveDataList::Handle m_curveDataList;  
   Image::Handle         m_image;
   Cursor::Handle        m_cursor; 
-  GraphManager::Handle  m_graphManager;
+//  GraphManager::Handle  m_graphManager;
   PlotOptions::Handle   m_options;
+
+  QwtPlotMarker        *m_marker;
+  QwtPlotGrid          *m_grid;
   //ModelFit              *m_modelFit;
 
   double m_range;
@@ -149,13 +163,12 @@ private:
   void setActiveCurve(CurveData::Handle,bool setCursor);
   void constructor();
   void setGraphOptions();
-  void drawMarker(int mouseXPos,int mouseYPos);
   void setCursorVolume(short vol);
 
-private slots:
-    virtual void mousePressed(const QMouseEvent &);
-    virtual void mouseMoved(const QMouseEvent &);
-    virtual void mouseReleased(const QMouseEvent  &);
+//private slots:
+//    virtual void mousePressed(const QMouseEvent &);
+//    virtual void mouseMoved(const QMouseEvent &);
+//    virtual void mouseReleased(const QMouseEvent  &);
 
 signals:
   void intensityChanged(float, float);
