@@ -9,12 +9,14 @@
 #if !defined(SINGLEWIDGET_H)
 #define SINGLEWIDGET_H
 
-#include "imagewidget.h"
+#include "imagewindow.h"
 #include "slicewidget.h"
 
 class QTimer;
+class QToolButton;
+class SliceView;
 
-class SingleWidget : public ImageWidget  
+class SingleWidget : public ImageWindow
 {
   Q_OBJECT
 public:
@@ -30,14 +32,18 @@ signals:
 
 private slots:
   void nextSlice();
-  void toggleSliceRoll(int);
-  void changeView();
   void setMovieFrameRate(int);
   void print();
 
+  virtual void on_actionSwitchViews_triggered();
+
+  virtual void on_actionSliceRollMode_toggled(bool);
+
 private:
+  void setLabels(const OverlayList*);
   void newSlice(int orient, int mode);
   SliceWidget::Handle  m_slice;
+  SliceView 		  *m_view;
   ImageGroup::Handle   m_image;
   QTimer              *m_sliceRollTimer;  
   QToolButton         *m_cursorModeButton;
