@@ -18,11 +18,14 @@
 #include "sliceviewbase.h"
 
 #include <string>
+#include <QPixmap>
 
 class OverlayList;
 class SliceWidget;
 
-class SliceView: public SliceViewBase
+std::string axisCodeToString(int code, bool lower);
+
+class SliceView: public QWidget, public Ui::SliceViewBase
 {
   Q_OBJECT
 public:
