@@ -13,6 +13,10 @@
 #include <qtimer.h>
 #include <qpixmap.h>
 #include <qapplication.h>
+//Added by qt3to4:
+#include <QShowEvent>
+#include <Q3Frame>
+#include <QDesktopWidget>
 
 #include "application.h"
 #include "splashscreen.h"
@@ -26,7 +30,7 @@
  * Display a splash screen for a few seconds and then invoke the app.
  */
 SplashScreen::SplashScreen(QWidget *parent, ApplicationOptions& opts, const char *name) 
-  : QFrame(parent, name, QWidget::WStyle_NoBorder | QWidget::WStyle_Customize), m_options(opts)
+  : Q3Frame(parent, name, Qt::WStyle_NoBorder | Qt::WStyle_Customize), m_options(opts)
 {
 
   #if !defined(WIN32)
@@ -42,7 +46,7 @@ SplashScreen::SplashScreen(QWidget *parent, ApplicationOptions& opts, const char
   setGeometry( (dw) - (w),
       	       (dh) - (h),
 	       pm.width(), pm.height() );
-  setFrameStyle( QFrame::Box | QFrame::Raised );
+  setFrameStyle( Q3Frame::Box | Q3Frame::Raised );
 
 
   show();
