@@ -9,11 +9,13 @@
 #if !defined(SPLASHSCREEN_H)
 #define SPLASHSCREEN_H
 
-#include <qframe.h>
+#include <q3frame.h>
+//Added by qt3to4:
+#include <QShowEvent>
 
 #include "options.h"
 
-class SplashScreen : public QFrame
+class SplashScreen : public Q3Frame
 {
   Q_OBJECT
 public:
