@@ -11,7 +11,8 @@
 
 #include "cursor.h"
 #include "overlaylist.h"
-#include "talairachwidgetbase.h"
+//#include "talairachwidgetbase.h"
+#include "atlasdockbase.h"
 #include "atlas.h"
 #include "atlasoptionsdialog.h"
 #include "atlasselectiondialog.h"
@@ -20,7 +21,8 @@
 
 class QStringList;
 
-class TalairachWidget : public TalairachWidgetBase, CursorObserver
+class TalairachWidget : public QDockWidget, private Ui_AtlasDockBase, 
+  public CursorObserver
 {
   Q_OBJECT
 
@@ -30,10 +32,14 @@ public:
 
   virtual void update(const Cursor::Handle& c);
 
-private slots:
-  void showSettingsDialog();
-  void showInspector();
-  void help();
+public slots:
+  void on_atlasesButton_clicked();
+  void on_helpButton_clicked();
+  void on_structuresButton_clicked();
+
+  /* void showSettingsDialog(); */
+  /* void showInspector(); */
+  /* void help(); */
 
 private:
   void readAtlas(const std::string&, const std::string&);
