@@ -3,7 +3,7 @@
 #include <qcombobox.h>
 
 TimeSeriesToolbar::TimeSeriesToolbar(QWidget *parent):
-    TimeSeriesToolbarBase(parent)
+    QWidget(parent)
 {
 }
 
