@@ -6,7 +6,7 @@
 
 class QWidget;
 
-class TimeSeriesToolbar: public TimeSeriesToolbarBase
+class TimeSeriesToolbar: public QWidget, public Ui::TimeSeriesToolbarBase
 {
 public:
   TimeSeriesToolbar(QWidget *parent = 0);
