@@ -2,7 +2,7 @@
 
     James Saunders, David Flitney and Stephen Smith, FMRIB Image Analysis Group
 
-    Copyright (C) 2002-2003 University of Oxford  */
+    Copyright (C) 2002-2012 University of Oxford  */
 
 /*  CCOPYRIGHT */
 
@@ -14,10 +14,12 @@
 #include <qlayout.h>
 #include <qpushbutton.h>
 #include <qspinbox.h>
-#include <qbuttongroup.h>
+#include <q3buttongroup.h>
 #include <qtoolbutton.h>
-#include <qtoolbar.h>
+#include <q3toolbar.h>
 #include <qtooltip.h>
+//Added by qt3to4:
+#include <QCloseEvent>
 #include <list>
 #include <qlabel.h>
 #include <qcheckbox.h>
@@ -26,15 +28,16 @@
 
 #include "singleserieswidget.h"
 
+#include <qwt_plot_picker.h>
+#include <qwt_plot_marker.h>
+#include <qwt_symbol.h>
 #include <qwt_plot.h>
 
-class Singleserieswidget;
-
-
 TimeSeriesWidget::TimeSeriesWidget(QWidget *parent, 
                                    Image::Handle& image, 
                                    Cursor::Handle& cursor):
-  TimeSeriesWindowBase(parent, 0, WDestructiveClose), m_image(image),
+  QWidget(parent),
+  m_image(image),
   m_cursor(cursor)
 {  
   m_options = PlotOptions::create();
@@ -46,7 +49,8 @@ TimeSeriesWidget::TimeSeriesWidget(QWidget *parent,
                                    Image::Handle& image, 
                                    Cursor::Handle& cursor,
                                    ModelFit::Handle& modelFit):
-  TimeSeriesWindowBase(parent, 0, WDestructiveClose), m_image(image),
+  QWidget(parent),
+  m_image(image),
   m_cursor(cursor)
 {  
   m_options = PlotOptions::create();
@@ -64,12 +68,18 @@ void TimeSeriesWidget::constructor()
 {  
   TRACKER("TimeSeriesWidget::constructor");  
 
+  setupUi(this);
+
   m_contrListIndex=0;
 
   layout()->remove(m_pixmap);	 // This section replaces the m_pixmap placeholder with a TSD
   delete m_pixmap;
-  m_displayWidget = TimeSeriesDisplay::Handle(new SingleSeriesWidget(this,m_image,m_cursor,m_options));
-  layout()->add(m_displayWidget.get());
+
+  m_plot = new SingleSeriesPlot(m_image,m_cursor,m_options, this);
+  connect(m_plot, SIGNAL(intensityChanged(float, float)),
+	  SLOT(intensityChanged(float, float)));
+
+  layout()->add(m_plot);
   layout()->remove(m_intensity); // Fudge to get the positioning correct
   layout()->add(m_intensity);
 
@@ -91,10 +101,20 @@ void TimeSeriesWidget::constructor()
 
   m_showAxes->setOn(true);
 
-  connect(m_displayWidget.get(), SIGNAL(intensityChanged(float, float)), 
-	  SLOT(intensityChanged(float, float)));
- 
-  m_displayWidget->show();
+  // Add a picker to the QwtPlot...
+  m_picker = new QwtPlotPicker(QwtPlot::xBottom, QwtPlot::yLeft,
+      QwtPicker::PointSelection | QwtPicker::DragSelection,
+      QwtPlotPicker::VLineRubberBand, QwtPicker::AlwaysOff,
+      m_plot->canvas());
+  m_picker->setRubberBandPen(QColor(Qt::green));
+  m_picker->setTrackerPen(QColor(Qt::white));
+  // ...and connect it's signals to this window's handlers
+  connect(m_picker, SIGNAL(moved(const QwtDoublePoint &)),
+          SLOT(moved(const QwtDoublePoint &)));
+  connect(m_picker, SIGNAL(selected(const QwtDoublePoint &)),
+          SLOT(selected(const QwtDoublePoint &)));
+
+  m_plot->show();
   m_cursor->setCursor(m_cursor->inqX(),m_cursor->inqY(),m_cursor->inqZ());
 }
 
@@ -102,6 +122,17 @@ TimeSeriesWidget::~TimeSeriesWidget()
 {
 }
 
+void TimeSeriesWidget::moved(const QwtDoublePoint& p)
+{
+	m_plot->drawMarker(p);
+}
+
+void TimeSeriesWidget::selected(const QwtDoublePoint& p)
+{
+	m_plot->selectNearestCurve(p);
+	m_plot->drawMarker(p);
+}
+
 void TimeSeriesWidget::intensityChanged(float x, float y)
 {
   m_intensity->setText(QString("Time: %1, Intensity: %2").arg(short(x)).arg(y));
@@ -124,7 +155,7 @@ void TimeSeriesWidget::printPressed()
 {
   QPrinter printer;
 
-  QString docName = m_displayWidget->title();
+  QString docName = m_plot->title().text();
   if ( docName.isEmpty() )
     {
       docName.replace (QRegExp (QString::fromLatin1 ("\n")), tr (" -- "));
@@ -135,7 +166,7 @@ void TimeSeriesWidget::printPressed()
   printer.setOrientation(QPrinter::Landscape);
 
   if (printer.setup())
-    m_displayWidget->print(printer, PrintFilter());
+    m_plot->print(printer);//, PrintFilter());
 }
 
 void TimeSeriesWidget::featModeToggled(bool y)
@@ -150,16 +181,14 @@ void TimeSeriesWidget::featModeToggled(bool y)
       m_modelCombo->insertItem("No model");
       m_modelCombo->insertItem("Full model only");
       for(unsigned int i=0; i<m_options->getModelFit()->numFits(); i++)
-	m_modelCombo->insertItem(m_options->getModelFit()->getConName(i));
-      m_modelCombo->setCurrentItem(1); // Full model only
-      modelComboActivated(1);
+    	  m_modelCombo->insertItem(m_options->getModelFit()->getConName(i));
     }
   else
     {
       m_add->setEnabled(true);
       m_remove->setEnabled(true);
     }
-  m_displayWidget->remAllTimeSeries();
+  m_plot->remAllTimeSeries();
   m_cursor->setCursor(m_cursor->inqX(),m_cursor->inqY(),m_cursor->inqZ());
 }
 
@@ -191,31 +220,31 @@ void TimeSeriesWidget::modelComboActivated(int item)
 
 void TimeSeriesWidget::removePressed()
 {
-  m_displayWidget->remTimeSeries();
+  m_plot->remTimeSeries();
 }
 
 void TimeSeriesWidget::addPressed()
 {
-  m_displayWidget->addTimeSeries();
+  m_plot->addTimeSeries();
 }
 
 void TimeSeriesWidget::demeanToggled(bool y)
 {
-  m_displayWidget->setDemean(y);
+  m_plot->setDemean(y);
   if( !y ) {
-    m_displayWidget->setPercent(y);
+    m_plot->setPercent(y);
     m_percent->setOn(false);
   }
-  m_displayWidget->redraw();
+  m_plot->redraw();
 }
 
 void TimeSeriesWidget::percentToggled(bool y)
 {
-  m_displayWidget->setPercent(y); 
-  m_displayWidget->redraw();
+  m_plot->setPercent(y);
+  m_plot->redraw();
 }
 
 void TimeSeriesWidget::showAxesToggled(bool y)
 {
-  m_displayWidget->axisDisplay(y);
+  m_plot->axisDisplay(y);
 }
