@@ -24,8 +24,11 @@ class QSpinBox;
 class QToolButton;
 class TimeSeriesPlot;
 class TimeSeriesToolbar;
+class QPoint;
 
-class TimeSeriesWidget : public TimeSeriesWindowBase
+#include <qwt_plot_picker.h>
+
+class TimeSeriesWidget : public QWidget, private Ui_TimeSeriesWindowBase
 {
   Q_OBJECT
 public:
@@ -53,7 +56,8 @@ private:
   //int              m_viewNumber;
   int              m_contrListIndex;
   
-  TimeSeriesDisplay::Handle  m_displayWidget;
+  SingleSeriesPlot *m_plot;
+  QwtPlotPicker *m_picker;
 
 public  slots:
   void closeEvent(QCloseEvent*);  
@@ -68,6 +72,10 @@ public  slots:
   void printPressed();
   void intensityChanged(float,float);
 
+//  void drawMarker(const QwtDoublePoint&);
+  void moved(const QwtDoublePoint&);
+  void selected(const QwtDoublePoint&);
+
 signals:
   void windowClose(QCloseEvent*);
 };
