@@ -5,9 +5,11 @@
 #include <qcheckbox.h>
 #include <qradiobutton.h>
 
-ViewOptionsDialog::ViewOptionsDialog(QWidget *p, ViewOptions& v):
-  ViewOptionsDialogBase(p)
+ViewOptionsDialog::ViewOptionsDialog(QWidget *p, ViewOptions& v)
+  : QDialog(p)
 {
+  setupUi(this);
+
   m_linkLocalVolume->setChecked(v.inqVolumeIndexingWithinView());
 
   m_linkGlobalVolume->setChecked(v.inqUseSharedVolume());
