@@ -5,7 +5,7 @@
 
 class ViewOptions;
 
-class ViewOptionsDialog: public ViewOptionsDialogBase
+class ViewOptionsDialog: public QDialog, public Ui_ViewOptionsDialogBase
 {
 Q_OBJECT
 
