@@ -8,13 +8,10 @@
 
 #include "viewwidget.h"
 
-#include <qgroupbox.h>
-#include <qlayout.h>
-
 #include "tracker.h"
 
 ViewWidget::ViewWidget(QWidget *parent)
-  : QMainWindow(parent, 0, WDestructiveClose)
+  : QMainWindow(parent, 0, Qt::WDestructiveClose)
 {
   TRACKER("ViewWidget::ViewWidget");
 }
