@@ -10,7 +10,8 @@
 #define VIEWWIDGET_H
 
 #include <boost/shared_ptr.hpp>
-#include <qmainwindow.h>
+
+#include <QtGui>
 
 #include "imagegroup.h"
 #include "cursor.h"
