@@ -22,8 +22,10 @@
 #include <qpushbutton.h>
 
 VTKPropertyDialog::VTKPropertyDialog(QWidget* parent, VTKProperties& props): 
-  VTKPropertyDialogBase(parent), m_props(props)
+  QDialog(parent), m_props(props)
 {
+  setupUi(this);
+
 //   m_lowerThreshold->setValue(m_props.inqLowerThreshold());
 //   m_upperThreshold->setValue(m_props.inqUpperThreshold());
   m_mcThreshold->setValidator(new QDoubleValidator(this));
