@@ -19,7 +19,7 @@
 
 class VTKProperties;
 
-class VTKPropertyDialog: public VTKPropertyDialogBase
+class VTKPropertyDialog: public QDialog, private Ui::VTKPropertyDialogBase
 {
 public:
   VTKPropertyDialog(QWidget* parent, VTKProperties& props);
