@@ -18,17 +18,20 @@
 #include <qspinbox.h>
 
 VTKToolbar::VTKToolbar(QWidget *parent, VTKProperties& p): 
-  VTKToolbarBase(parent), m_props(p) 
+  QWidget(parent), m_props(p) 
 {
-  m_threshold->setValue(m_props.inqLowerThreshold());
+  setupUi(this);
+
+  threshold->setValue(m_props.inqLowerThreshold());
 }
 
-void VTKToolbar::thresholdValueChanged(int v)
+void VTKToolbar::on_threshold_valueChanged(int v)
 {
+  cout << v << endl;
   m_props.setLowerThreshold(v);
 }  
 
-void VTKToolbar::clippingStateChanged(int state)
+void VTKToolbar::on_clipping_stateChanged(int state)
 {
   m_props.setClipping(state);
 }
