@@ -19,14 +19,16 @@
 
 class VTKProperties;
 
-class VTKToolbar: public VTKToolbarBase
+class VTKToolbar: public QWidget, public Ui::VTKToolbarBase
 {
+  Q_OBJECT
+
 public:
   VTKToolbar(QWidget *, VTKProperties&);
 
 private slots:
-  void thresholdValueChanged(int);
-  void clippingStateChanged(int);
+  void on_threshold_valueChanged(int);
+  void on_clipping_stateChanged(int);
 
 private:
   VTKProperties &m_props;
