@@ -18,7 +18,8 @@
 #include <map>
 
 #include <qapplication.h>
-#include <qfiledialog.h>
+#include <QToolBar>
+#include <q3filedialog.h>
 
 #include "vtkwidget.h"
 #include "maintoolbar.h"
@@ -747,21 +748,28 @@ VTKWidget::VTKWidget(QWidget *parent,
 		     ImageGroup::Handle i,
 		     OverlayList::Handle ol, 
 		     Cursor::Handle c) :  
-  ImageWidget(parent,i,ol,c), m_impl(new Implementation(this, ol)), m_image(i)
+//  ImageWidget(parent, i,ol,c), m_impl(new Implementation(this, ol)), m_image(i)
+  ImageWindow(i,ol,c,parent), m_impl(new Implementation(this, ol)), m_image(i)
 {
   TRACKER("VTKWidget::VTKWidget");
   
   QApplication::setOverrideCursor( QCursor(Qt::WaitCursor) );
 
-  m_vtkwidget = new QVTKWidget( this, "vtkWidget" );
-  setCentralWidget(m_vtkwidget);
+  m_vtkwidget = new QVTKWidget( this );
+  m_grid->addWidget(m_vtkwidget);
+//  setCentralWidget(m_vtkwidget);
 
-  QToolBar *tb = new QToolBar(this);
-  VTKToolbar *vt = new VTKToolbar(tb, m_impl->m_props);
+  QToolBar *tb = addToolBar(tr("VTK Rendering Tools"));
+  VTKToolbar *vt = new VTKToolbar(this, m_impl->m_props);
+  tb->addWidget(vt);
+  m_vtkToolBar->hide();
 
-  addDockWindow(tb, tr("VTK Rendering Tools"), Top, FALSE);  
-  m_toolbar->hide();
-  m_modebar->hide();
+  //  addDockWindow(tb, tr("VTK Rendering Tools"), Qt::DockTop, FALSE);  
+  m_mainToolBar->hide();
+  m_drawToolBar->hide();
+  m_movieModeToolBar->hide();
+  actionSwitchViews->setEnabled(false);
+//  m_modebar->hide();
 
   connect(vt->m_printButton,   SIGNAL(clicked()), SLOT(print()));
   connect(vt->m_optionsButton, SIGNAL(clicked()), SLOT(options()));
@@ -771,7 +779,9 @@ VTKWidget::VTKWidget(QWidget *parent,
   vtkRenderer *ren = vtkRenderer::New();
   m_impl->m_renderer=ren;
   ren->SetBackground(0.4, 0.4, 0.4);
-  m_vtkwidget->GetRenderWindow()->AddRenderer(ren);
+  vtkRenderWindow *renwin = vtkRenderWindow::New();
+  renwin->AddRenderer(ren);
+  m_vtkwidget->SetRenderWindow(renwin);
 
   //  LookUpTableFactory *lut = new LookUpTableFactory();
     
@@ -1063,7 +1073,7 @@ VTKWidget::VTKWidget(QWidget *parent,
   
   // Reset camera
   ren->ResetCamera();
-  m_vtkwidget->GetRenderWindow()->Render();
+  //m_vtkwidget->GetRenderWindow()->Render();
   QApplication::restoreOverrideCursor();
 
   m_impl->m_ol->attach(this);
@@ -1088,7 +1098,7 @@ void VTKWidget::addMesh()
 {
   //FileDialog to find mesh file
 
-  QString fn = QFileDialog::getOpenFileName(QDir::currentDirPath(),
+  QString fn = Q3FileDialog::getOpenFileName(QDir::currentDirPath(),
 					    "Mesh files (*.vtk)", 
 					    this );
   if(!fn.isEmpty()) 
@@ -1096,7 +1106,7 @@ void VTKWidget::addMesh()
       QApplication::setOverrideCursor( QCursor(Qt::WaitCursor) );
       ImageInfo::Handle info(m_impl->m_ol->getMainMetaImage()->getInfo());
       float xoff(info->inqXDim() * (info->inqX() - 1));
-      VTKMeshSurface::Handle mesh = VTKMeshSurface::create(m_impl->m_renderer, fn, xoff);
+      VTKMeshSurface::Handle mesh = VTKMeshSurface::create(m_impl->m_renderer, fn.toUtf8().constData(), xoff);
       m_impl->m_meshes.push_back(mesh);
       m_impl->m_renderer->AddViewProp(mesh->getActor());
       m_impl->m_renderer->AddViewProp(mesh->getGlyphActor());
@@ -1189,7 +1199,7 @@ void VTKWidget::update(const OverlayList *ol, OverlayListMsg msg)
 
 void VTKWidget::print() 
 {
-  QString fn = QFileDialog::getSaveFileName("screenshot.tiff", 
+  QString fn = Q3FileDialog::getSaveFileName("screenshot.tiff", 
 					    "TIFF files (*.tif, *.tiff)", this,
 					    "Screenshot dialog",
 					    "Select a filename for saving");
