@@ -15,7 +15,7 @@
 #if !defined(VTKWIDGET_H)
 #define VTKWIDGET_H
 
-#include "imagewidget.h"
+#include "imagewindow.h"
 
 #include <boost/shared_ptr.hpp>
 #include <vtkProperty.h>
@@ -128,7 +128,7 @@ public:
   virtual ~VTKPropertiesObserver() {}
 };
 
-class VTKWidget : public ImageWidget, public VTKPropertiesObserver, public BriConObserver
+class VTKWidget : public ImageWindow, public VTKPropertiesObserver
 {
   Q_OBJECT
 public:
@@ -147,6 +147,7 @@ private slots:
   void options();
   void addMesh();
   void meshOptions();
+  virtual void on_actionSwitchViews_triggered() {}
   
 
 private:
