@@ -84,8 +84,12 @@ ImageInfo::ImageInfo(short x,short y,short z,short v,short dt,
 ImageInfo::ImageInfo(FSLIO *avw,std::string filename):m_fileName(filename)
 {
   float p1, p2, p3;
+  size_t dim;
   m_bitsPerVoxel = FslGetDataType(avw, &m_dt);
   FslGetDim(avw, &m_x, &m_y, &m_z, &m_v);
+  FslGetDimensionality(avw, &dim);
+  if (dim == 3)
+	  m_v = 1;
   FslGetVoxDim(avw, &m_xDim, &m_yDim, &m_zDim, &m_tr);
   FslGetAuxFile(avw,&m_auxFile[0]);
 //   if(strlen(m_auxFile) != 0) {
@@ -164,6 +168,13 @@ std::string ImageInfo::inqDtAsString() const
     case 64:  result = std::string("Double");        break;
     case 128: result = std::string("RGB");           break;
     case 255: result = std::string("All");           break;
+    case 256: result = std::string("Char");          break;
+    case 512: result = std::string("Unsigned short");break;
+    case 768: result = std::string("Unsigned int");  break;
+    case 1024:result = std::string("Long long");     break;
+    case 1280:result = std::string("Unsigned long"); break;
+    case 1536:result = std::string("Long double");   break;
+    
     default: result = std::string("Unknown DT: " + inqDt()); break;
     }
 
