@@ -50,6 +50,14 @@ public:
   float inqYDim() const;
   float inqZDim() const;
 
+  // NEWIMAGE compatability interface
+  inline int xsize() const { return inqX(); }
+  inline int ysize() const { return inqY(); }
+  inline int zsize() const { return inqZ(); }
+  inline float xdim() const { return inqXDim(); }
+  inline float ydim() const { return inqYDim(); }
+  inline float zdim() const { return inqZDim(); }
+ 
   float inqTr() const;
   short inqDt() const;
   std::string inqDtAsString() const;
