@@ -21,8 +21,14 @@ Volume& Volume::operator=(const Volume& rhs)
   return *this;
 }
 
+template class VolumeStore<char>;
 template class VolumeStore<unsigned char>;
 template class VolumeStore<short>;
+template class VolumeStore<unsigned short>;
 template class VolumeStore<int>;
+template class VolumeStore<unsigned int>;
+template class VolumeStore<long long>;
+template class VolumeStore<unsigned long long>;
 template class VolumeStore<float>;
 template class VolumeStore<double>;
+template class VolumeStore<long double>;
