@@ -107,12 +107,19 @@ private:
   VoxelType* m_buffer;
 };
 
-typedef VolumeStore<unsigned char> VolumeB;
+typedef VolumeStore<unsigned char> VolumeUB;
 typedef VolumeStore<short>         VolumeS;
 typedef VolumeStore<int>           VolumeI;
 typedef VolumeStore<float>         VolumeF;
 typedef VolumeStore<double>        VolumeD;
 
+typedef VolumeStore<char>				VolumeB;
+typedef VolumeStore<unsigned short>		VolumeUS;
+typedef VolumeStore<unsigned int>		VolumeUI;
+typedef VolumeStore<long long>			VolumeI64;
+typedef VolumeStore<unsigned long long>	VolumeUI64;
+typedef VolumeStore<long double>		VolumeF128;
+
 #include "volume.inc"
 
 #endif
